==> advi_1.4.0.orig.tar.gz: advi-1.4.0/gs.mli <==
(***********************************************************************)
(*                                                                     *)
(*                             Active-DVI                              *)
(*                                                                     *)
(*                   Projet Cristal, INRIA Rocquencourt                *)
(*                                                                     *)
(*  Copyright 2002 Institut National de Recherche en Informatique et   *)
(*  en Automatique.  All rights reserved.  This file is distributed    *)
(*  under the terms of the GNU Lesser General Public License.          *)
(*                                                                     *)
(*  Jun Furuse, Didier Rmy and Pierre Weis.                           *)
(*  Contributions by Roberto Di Cosmo, Didier Le Botlan,               *)
(*  Xavier Leroy, and Alan Schmitt.                                    *)
(*                                                                     *)
(*  Based on Mldvi by Alexandre Miquel.                                *)
(***********************************************************************)

(* $Id: gs.mli,v 1.5 2003/01/06 10:49:12 weis Exp $ *)

exception Terminated;;
val kill : unit -> unit;;
val draw : string -> int -> int -> unit;;
val add_headers : (bool * string) list -> unit;;
val newpage : (bool * string) list -> int -> float -> int -> int -> unit;;
val flush : unit -> unit;;
val toggle_antialiasing : unit -> unit;;
val current_x : int ref;;
val current_y : int ref;;

==> advi_1.6.0.orig.tar.gz: advi-1.6.0/gs.mli <==
(***********************************************************************)
(*                                                                     *)
(*                             Active-DVI                              *)
(*                                                                     *)
(*                   Projet Cristal, INRIA Rocquencourt                *)
(*                                                                     *)
(*  Copyright 2002 Institut National de Recherche en Informatique et   *)
(*  en Automatique.  All rights reserved.  This file is distributed    *)
(*  under the terms of the GNU Lesser General Public License.          *)
(*                                                                     *)
(*  Jun Furuse, Didier Rmy and Pierre Weis.                           *)
(*  Contributions by Roberto Di Cosmo, Didier Le Botlan,               *)
(*  Xavier Leroy, and Alan Schmitt.                                    *)
(*                                                                     *)
(*  Based on Mldvi by Alexandre Miquel.                                *)
(***********************************************************************)

(* $Id: gs.mli,v 1.11 2003/11/12 07:53:05 remy Exp $ *)

exception Terminated;;
val kill : unit -> unit;;
val draw : string -> int -> int -> unit;;
val draw_file : string -> int * int * int * int -> int * int -> 
  int -> int -> unit;;
val add_headers : (bool * string) list -> unit;;
val newpage : (bool * string) list -> int -> float -> int -> int -> unit;;
val flush : unit -> unit;;
val toggle_antialiasing : unit -> unit;;
val current_point : unit -> int * int;;

val get_do_ps : unit -> bool;;
val set_do_ps : bool -> unit;;
val init_do_ps : unit -> unit;;
(** Handling the [do_ps] flag that governs the use of gv
  to display PostScript. *)
